const mongoose = require('mongoose')
const Bcrypt   = require('bcrypt')
const Boom     = require('@hapi/boom')

const UserSchema = new mongoose.Schema({
  email     : {type: String, required: true, index:{unique: true}},
  password  : {type: String, required: true}
});
UserSchema.statics.authenticate = async function authenticate({ email, password }) {
  const user = await this.findOne({ email })
  const invalid = !user || !await Bcrypt.compare(password, user.password)
  if (invalid) {
    throw Boom.forbidden('Email and|or password doesn\'t match')
  }
  return user;
}
UserSchema.statics.signUp = async function signUp({ email, password }) {
    const user = await this.findOne({ email })
    if (user) {
      throw Boom.conflict('User already exists')
    }
    const encryptedPassword = await Bcrypt.hash(password, 10)
    return new this({
      email,
      password: encryptedPassword
    }).save()
}

const User = mongoose.model('user', UserSchema)
module.exports = User;